# Concept Exploration: <descriptive title of exploration challenge>

- [Concept Exploration: ](#concept-exploration-)
- [Prompt to identify and specify the major building blocks of the archictural concept](#prompt-to-identify-and-specify-the-major-building-blocks-of-the-archictural-concept)
- [refine architecture prompt](#refine-architecture-prompt)

# Prompt to identify and specify the major building blocks of the archictural concept
given the vision statement of <...>
```
```

and given the business goal of <...>
```
```

and given the customer profile <...>
```
```

and given the targeted capabilities <...>
```
```

and given the targeted key features <...>
```
```

and given further known functional requirements
```
* list of known functional requirements if any
```

and given further known non functional requirements
```
* list of known non functional requirements if any
```

and given any upfront decided technical constraint
```
```

create a well balanced architecture design concept as a senior software architect would do it by using the following format template:
```
# Title: <descriptive title of the architecture concept>

- [Title: ](#title-)
- [Decision for Architecture Design](#decision-for-architecture-design)
  - [functional major decisions](#functional-major-decisions)
  - [non functional major decisions](#non-functional-major-decisions)
- [Component Diagram in plantuml](#component-diagram-in-plantuml)
- [Deployment diagram in plantuml](#deployment-diagram-in-plantuml)

# Decision for Architecture Design
## functional major decisions
<list of major functional decisions of the concept>

## non functional major decisions
<list of major non functional decisions of the concept>

# Component Diagram in plantuml
```

```
Description: <description of the purpose and the value of the components of the diagram>

# Deployment diagram in plantuml
```

```
Description: <description of the purpose and the value of the building blocks of the diagram>
```

Explain why this design concept contributes perfectly to the list of the given constraints.

# refine architecture prompt
...
